@@ -18,7 +18,8 @@ import warnings
 from typing import Callable, Any, Union
 
 from pm4py.objects.log import obj as log_inst
-from pm4py.utils import general_checks_classical_event_log
+import pandas as pd
+from pm4py.objects.log.obj import EventLog, EventStream
 
 
 def filter_log(f: Callable[[Any], bool], log: log_inst.EventLog) -> Union[log_inst.EventLog, log_inst.EventStream]:
@@ -38,7 +39,8 @@ def filter_log(f: Callable[[Any], bool], log: log_inst.EventLog) -> Union[log_in
         filtered event log if object provided is correct; original log if not correct
 
     """
-    general_checks_classical_event_log(log)
+    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
+
     if isinstance(log, log_inst.EventLog):
         return log_inst.EventLog(list(filter(f, log)), attributes=log.attributes, classifiers=log.classifiers,
                                  omni_present=log.omni_present, extensions=log.extensions, properties=log.properties)
@@ -89,7 +91,8 @@ def sort_log(log: log_inst.EventLog, key, reverse: bool = False) -> Union[log_in
     -------
         sorted event log if object provided is correct; original log if not correct
     """
-    general_checks_classical_event_log(log)
+    if type(log) not in [pd.DataFrame, EventLog, EventStream]: raise Exception("the method can be applied only to a traditional event log!")
+
     if isinstance(log, log_inst.EventLog):
         return log_inst.EventLog(sorted(log, key=key, reverse=reverse), attributes=log.attributes,
                                  classifiers=log.classifiers, omni_present=log.omni_present, extensions=log.extensions, properties=log.properties)
