@@ -15,3 +15,7 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from pm4py.objects.petri.exporter import variants, exporter
+
+import warnings
+
+warnings.warn('please use the pm4py.objects.petri_net.exporter package instead.')
