@@ -20,10 +20,11 @@ from copy import copy, deepcopy
 
 from pm4py.objects.log.obj import Trace, Event
 from pm4py.objects.petri_net import properties
-from pm4py.objects.petri_net import semantics
+from pm4py.objects.petri_net import semantics, properties
 from pm4py.objects.petri_net.utils.networkx_graph import create_networkx_directed_graph
 from pm4py.objects.petri_net.obj import PetriNet, Marking
 from pm4py.util import xes_constants as xes_util
+import deprecation
 
 
 def is_sub_marking(sub_marking, marking):
@@ -42,17 +43,25 @@ def place_set_as_marking(places):
     return m
 
 
-def pre_set(elem):
+def get_arc_type(elem):
+    if properties.ARCTYPE in elem.properties:
+        return elem.properties[properties.ARCTYPE]
+    return None
+
+
+def pre_set(elem, arc_type=None):
     pre = set()
     for a in elem.in_arcs:
-        pre.add(a.source)
+        if get_arc_type(a) == arc_type:
+            pre.add(a.source)
     return pre
 
 
-def post_set(elem):
+def post_set(elem, arc_type=None):
     post = set()
     for a in elem.out_arcs:
-        post.add(a.target)
+        if get_arc_type(a) == arc_type:
+            post.add(a.target)
     return post
 
 
@@ -310,6 +319,7 @@ def get_transition_by_name(net, transition_name):
     return None
 
 
+@deprecation.deprecated('2.2.7', '3.0.0')
 def get_cycles_petri_net_places(net):
     """
     Get the cycles of a Petri net (returning only list of places belonging to the cycle)
@@ -337,6 +347,7 @@ def get_cycles_petri_net_places(net):
     return cycles_places
 
 
+@deprecation.deprecated('2.2.7', '3.0.0')
 def get_cycles_petri_net_transitions(net):
     """
     Get the cycles of a Petri net (returning only list of transitions belonging to the cycle)
@@ -407,6 +418,7 @@ def decorate_transitions_prepostset(net):
         trans.add_marking = add_marking
 
 
+@deprecation.deprecated('2.2.7', '3.0.0')
 def get_strongly_connected_subnets(net):
     """
     Get the strongly connected components subnets in the Petri net
